summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ChangeLog9
-rw-r--r--doc/tmpl/glade-project.sgml9
-rw-r--r--doc/tmpl/gladeui-unused.sgml8
-rw-r--r--gladeui/glade-widget-adaptor.c38
-rw-r--r--plugins/gtk+/gtk+.xml.in15
5 files changed, 48 insertions, 31 deletions
diff --git a/ChangeLog b/ChangeLog
index dc3ad77d..113830c3 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,12 @@
+2007-12-20 Juan Pablo Ugarte <juanpablougarte@gmail.com>
+
+ * plugins/gtk+/gtk+.xml.in:
+ updated displayable values for GtkButtonBox::layout-style
+ added displayable values for GtkEntry::shadow-type
+
+ * gladeui/glade-widget-adaptor.c: fixed bug #477025 "missing icones"
+ create_icon_name_for_adaptor() renamed to create_icon_name_for_adaptor()
+
2007-12-19 Christian Persch <chpe@gnome.org>
* configure.ac:
diff --git a/doc/tmpl/glade-project.sgml b/doc/tmpl/glade-project.sgml
index f26c1fdd..9e52f18a 100644
--- a/doc/tmpl/glade-project.sgml
+++ b/doc/tmpl/glade-project.sgml
@@ -321,15 +321,6 @@ GladeProject
@old_name:
-<!-- ##### FUNCTION glade_project_get_tooltips ##### -->
-<para>
-
-</para>
-
-@project:
-@Returns:
-
-
<!-- ##### FUNCTION glade_project_is_selected ##### -->
<para>
diff --git a/doc/tmpl/gladeui-unused.sgml b/doc/tmpl/gladeui-unused.sgml
index 17d6b04d..b5019aa9 100644
--- a/doc/tmpl/gladeui-unused.sgml
+++ b/doc/tmpl/gladeui-unused.sgml
@@ -76,6 +76,14 @@ GladeWidgetClass
@motion_notify_event:
@event:
+<!-- ##### FUNCTION glade_project_get_tooltips ##### -->
+<para>
+
+</para>
+
+@project:
+@Returns:
+
<!-- ##### FUNCTION glade_util_queue_draw_nodes ##### -->
<para>
diff --git a/plugins/gtk+/gtk+.xml.in b/plugins/gtk+/gtk+.xml.in
index 45c22bd7..221c7709 100644
--- a/plugins/gtk+/gtk+.xml.in
+++ b/plugins/gtk+/gtk+.xml.in
@@ -313,7 +313,7 @@ embedded in another object</_tooltip>
</properties>
</glade-widget-class>
- <glade-widget-class name="GtkMenuShell" generic-name="menushell" _title="Menu Shell" use-placeholders="False">
+ <glade-widget-class name="GtkMenuShell" _title="Menu Shell" use-placeholders="False">
<post-create-function>empty</post-create-function>
<add-child-function>glade_gtk_menu_shell_add_child</add-child-function>
<remove-child-function>glade_gtk_menu_shell_remove_child</remove-child-function>
@@ -593,7 +593,15 @@ embedded in another object</_tooltip>
<post-create-function>glade_gtk_entry_post_create</post-create-function>
<properties>
<property id="text" translatable="True"/>
-
+ <property id="shadow-type">
+ <displayable-values>
+ <value id="GTK_SHADOW_NONE" _name="None"/>
+ <value id="GTK_SHADOW_IN" _name="In"/>
+ <value id="GTK_SHADOW_OUT" _name="Out"/>
+ <value id="GTK_SHADOW_ETCHED_IN" _name="Etched In"/>
+ <value id="GTK_SHADOW_ETCHED_OUT" _name="Etched Out"/>
+ </displayable-values>
+ </property>
<!-- Atk activate property -->
<property id="atk-activate" _name="Activate" ignore="True" atk-action="True">
<_tooltip>Set the description of the Activate atk action</_tooltip>
@@ -1164,11 +1172,12 @@ embedded in another object</_tooltip>
<properties>
<property id="layout-style">
<displayable-values>
- <value id="GTK_BUTTONBOX_DEFAULT_STYLE" _name="Default"/>
+ <value id="GTK_BUTTONBOX_DEFAULT_STYLE" _name="Default"/>
<value id="GTK_BUTTONBOX_SPREAD" _name="Spread"/>
<value id="GTK_BUTTONBOX_EDGE" _name="Edge"/>
<value id="GTK_BUTTONBOX_START" _name="Start"/>
<value id="GTK_BUTTONBOX_END" _name="End"/>
+ <value id="GTK_BUTTONBOX_CENTER" _name="Center"/>
</displayable-values>
</property>
</properties>
diff --git a/gladeui/glade-widget-adaptor.c b/gladeui/glade-widget-adaptor.c
index 20e0414a..a4035df3 100644
--- a/gladeui/glade-widget-adaptor.c
+++ b/gladeui/glade-widget-adaptor.c
@@ -1429,29 +1429,29 @@ gwa_extend_with_node (GladeWidgetAdaptor *adaptor,
}
/**
* create_icon_name_for_adaptor:
* @adaptor_name: The name of the widget class
* @adaptor_type: The #GType of the adaptor class
* @icon_name: The icon name as set from the catalog
* @icon_prefix: The icon prefix as set from the catalog
* @generic_name: The generic name for the widget class
*
* Creates a suitable icon name for an adaptor, based on several parameters.
*
* Returns: An icon name, or NULL if the adaptor does not require one.
*/
static gchar *
-create_icon_name_for_adaptor (const gchar *adaptor_name,
- GType adaptor_type,
- const gchar *icon_name,
- const gchar *icon_prefix,
- const gchar *generic_name)
+create_icon_name_for_object_class (const gchar *class_name,
+ GType class_type,
+ const gchar *icon_name,
+ const gchar *icon_prefix,
+ const gchar *generic_name)
{
gchar *name;
- /* only certain widget adaptors need to have icons */
- if (G_TYPE_IS_INSTANTIATABLE (adaptor_type) == FALSE ||
- G_TYPE_IS_ABSTRACT (adaptor_type) != FALSE ||
+ /* only certain object classes need to have icons */
+ if (G_TYPE_IS_INSTANTIATABLE (class_type) == FALSE ||
+ G_TYPE_IS_ABSTRACT (class_type) != FALSE ||
generic_name == NULL)
{
return NULL;
@@ -1466,7 +1466,7 @@ create_icon_name_for_adaptor (const gchar *adaptor_name,
/* check if icon is available */
if (!gtk_icon_theme_has_icon (gtk_icon_theme_get_default (), name))
{
- g_warning ("No icon named '%s' was found for widget class '%s'.", name, adaptor_name);
+ g_warning ("No icon named '%s' was found for object class '%s'.", name, class_name);
g_free (name);
name = g_strdup (DEFAULT_ICON_NAME);
}
@@ -1627,11 +1627,11 @@ glade_widget_adaptor_from_catalog (GladeXmlNode *class_node,
icon_name = glade_xml_get_property_string (class_node, GLADE_TAG_ICON_NAME);
/* get a suitable icon name for adaptor */
- adaptor_icon_name = create_icon_name_for_adaptor (name,
- adaptor_type,
- icon_name,
- icon_prefix,
- generic_name);
+ adaptor_icon_name = create_icon_name_for_object_class (name,
+ object_type,
+ icon_name,
+ icon_prefix,
+ generic_name);
adaptor = g_object_new (adaptor_type,
"type", object_type,
@@ -1429,29 +1429,29 @@ gwa_extend_with_node (GladeWidgetAdaptor *adaptor,
}
/**
- * create_icon_name_for_adaptor:
- * @adaptor_name: The name of the widget class
- * @adaptor_type: The #GType of the adaptor class
+ * create_icon_name_for_object_class:
+ * @class_name: The name of the widget class
+ * @class_type: The #GType of the adaptor class
* @icon_name: The icon name as set from the catalog
* @icon_prefix: The icon prefix as set from the catalog
@@ -1429,29 +1429,29 @@ gwa_extend_with_node (GladeWidgetAdaptor *adaptor,
* @generic_name: The generic name for the widget class
*
- * Creates a suitable icon name for an adaptor, based on several parameters.
+ * Creates a suitable icon name for an object class, based on several parameters.
*
@@ -1429,29 +1429,29 @@ gwa_extend_with_node (GladeWidgetAdaptor *adaptor,
*
- * Returns: An icon name, or NULL if the adaptor does not require one.
+ * Returns: An icon name, or NULL if the object class does not require one.
*/
static gchar *